@@ -102,6 +102,8 @@ class Panda(QtGui.QMainWindow): #main class
 		if self.os != "RX-51": #check for N900 
 			self.ui.albumArt.setStyleSheet("background-color: rgb(255, 255, 255);")
 
+		self.ui.btnHate.setStyleSheet("background-color: rgb(100, 100, 100);\nborder: rgb(255, 255, 255);\nbackground-image: url(:/img/img/thumbdwn_small.png);")
+
 		if not self.c.lastplayed == "": #auto-play last station
 			self.player.playStation = self.c.lastplayed
 		try : #test for rotation and set auto-rotation on
@@ -151,6 +153,7 @@ class Panda(QtGui.QMainWindow): #main class
 				self.setUi ( self.player.curSong )
 				self.buildPlaylist()
 		print "Orientation Changed"
+		self.ui.lblTime.setWordWrap( True )
 
 	def connect_signals( self ): #connect all signals
 		if not self.authenticated:
@@ -165,7 +168,7 @@ class Panda(QtGui.QMainWindow): #main class
 		QtCore.QObject.connect(self.ui.btnNext, QtCore.SIGNAL('released()'), self.nextUp)
 		QtCore.QObject.connect(self.ui.btnHate, QtCore.SIGNAL('pressed()'), self.hateDown)
 		QtCore.QObject.connect(self.ui.btnHate, QtCore.SIGNAL('released()'), self.hateUp)
-		QtCore.QObject.connect(self.ui.btnNext, QtCore.SIGNAL('clicked()'), self.skipSong)
+		QtCore.QObject.connect(self.ui.btnNext, QtCore.SIGNAL('clicked()'), self.playNextSong)
 		QtCore.QObject.connect(self.ui.btnHate, QtCore.SIGNAL('clicked()'), self.doHate)
 		QtCore.QObject.connect(self.ui.btnPlay, QtCore.SIGNAL('clicked()'), self.doPlayPause)
 		QtCore.QObject.connect(self.ui.btnLove, QtCore.SIGNAL('clicked()'), self.doLove)
@@ -181,14 +184,123 @@ class Panda(QtGui.QMainWindow): #main class
 		QtCore.QObject.connect(self.player,QtCore.SIGNAL("duration"), self.setDuration)
 		QtCore.QObject.connect(self.player,QtCore.SIGNAL("state(QString)"), self.doPlayPause)
 		QtCore.QObject.connect(self.s, QtCore.SIGNAL('shutdown'), self.closeEvent)
-		QtCore.QObject.connect(self.ui.actionUser_Pass, QtCore.SIGNAL('triggered()'), self.setUserPass)
 		QtCore.QObject.connect(self.ui.actionDelete, QtCore.SIGNAL('triggered()'), self.deleteStation)
 		QtCore.QObject.connect(self.ui.actionEnable_FM_Radio, QtCore.SIGNAL('triggered()'), self.doFM)
 		QtCore.QObject.connect(self.ui.actionSnooze, QtCore.SIGNAL('triggered()'), self.setSnooze)
 		QtCore.QObject.connect(self.ui.actionCreate, QtCore.SIGNAL('triggered()'), self.createStation)
 		QtCore.QObject.connect(self.ui.actionDonate, QtCore.SIGNAL('triggered()'), self.open_donate)
-		QtCore.QObject.connect(self.ui.actionQuality, QtCore.SIGNAL('triggered()'), self.open_quality)
 		QtCore.QObject.connect(self.ui.actionAdd_Seed, QtCore.SIGNAL('triggered()'), self.doSeed)
+		QtCore.QObject.connect(self.ui.actionSettings, QtCore.SIGNAL('triggered()'), self.openSettings)
+
+	def openSettings( self ): #Build and open settings dialog box.
+		self.d = QDialog(self)
+		self.d.setParent(self)
+		self.settings = {} #Store settings in a hash, it's easier to read in my opinion.
+		if self.os == "RX-51":
+			if not self.portrait:
+				self.d.setAttribute(Qt.WA_Maemo5LandscapeOrientation, 1)
+			else:
+				self.d.setAttribute(Qt.WA_Maemo5PortraitOrientation, 1)
+		vbox = QVBoxLayout()
+		hLayout = QHBoxLayout()
+		hLayout2 = QHBoxLayout()
+		hLayout3 = QHBoxLayout()
+		hLayout4 = QHBoxLayout()
+		hLayout5 = QHBoxLayout()
+		self.settings['lblUsername'] = QLabel("Username:")
+		self.settings['lineUser'] = QLineEdit()
+		self.settings['lblUsername'].setBuddy(self.settings['lineUser'])
+		self.settings['lineUser'].setText(self.c.user)
+		self.settings['lblPass'] = QLabel("Password:")
+		self.settings['linePass'] = QLineEdit()
+		self.settings['lblPass'].setBuddy(self.settings['linePass'])
+		self.settings['linePass'].setText(self.c.password)
+		self.settings['linePass'].setEchoMode(QLineEdit.Password)
+		self.settings['btnGroup'] = QButtonGroup()
+		self.settings['radioHigh'] = QRadioButton("High (Pandora One)")
+		self.settings['radioMed'] = QRadioButton("Medium (MP3)")
+		self.settings['radioLow'] = QRadioButton("Low (AAC)")
+		self.settings['btnGroup'].addButton(self.settings['radioHigh'])
+		self.settings['btnGroup'].addButton(self.settings['radioMed'])
+		self.settings['btnGroup'].addButton(self.settings['radioLow'])
+		if self.c.format == "mp3-hifi":
+			self.settings['radioHigh'].setChecked(1)
+		elif self.c.format == "mp3":
+			self.settings['radioMed'].setChecked(1)
+		elif self.c.format == "aacplus":
+			self.settings['radioLow'].setChecked(1)
+		else:
+			self.settings['radioMed'].setChecked(1)
+		self.settings['btnGroup2'] = QButtonGroup()
+		self.settings['radioAuto'] = QRadioButton("Automatic")
+		self.settings['radioPort'] = QRadioButton("Portrait")
+		self.settings['radioLand'] = QRadioButton("Landscape")
+		if not self.portrait:
+			self.settings['radioAuto'].setChecked(1)
+		else:
+			self.settings['radioPort'].setChecked(1)
+		self.settings['btnGroup2'].addButton(self.settings['radioAuto'])
+		self.settings['btnGroup2'].addButton(self.settings['radioPort'])
+		self.settings['btnGroup2'].addButton(self.settings['radioLand'])
+		a = QPushButton("Accept")
+		b = QPushButton("Cancel")
+		hLayout.addWidget(self.settings['lblUsername'])
+		hLayout.addWidget(self.settings['lineUser'])
+		hLayout2.addWidget(self.settings['lblPass'])
+		hLayout2.addWidget(self.settings['linePass'])
+		hLayout3.addWidget(self.settings['radioHigh'])
+		hLayout3.addWidget(self.settings['radioMed'])
+		hLayout3.addWidget(self.settings['radioLow'])
+		hLayout4.addWidget(self.settings['radioAuto'])
+		hLayout4.addWidget(self.settings['radioPort'])
+		hLayout4.addWidget(self.settings['radioLand'])
+		hLayout5.addWidget(a)
+		hLayout5.addWidget(b)
+		a.clicked.connect(self.setSettings)
+		b.clicked.connect(self.d.close)
+		vbox.addLayout(hLayout)
+		vbox.addLayout(hLayout2)
+		vbox.addLayout(hLayout3)
+		if self.player.os == "RX-51":
+			vbox.addLayout(hLayout4)
+		vbox.addLayout(hLayout5)
+		self.d.setLayout(vbox)
+		self.d.setWindowTitle("pyRadio Settings:")
+		self.d.show()
+
+	def setSettings ( self ): #Set settings.
+		changed = False
+		if self.c.user != self.settings['lineUser'].text() or self.c.password != self.settings['linePass'].text():
+			self.c.user = self.settings['lineUser'].text()
+			self.c.password = self.settings['linePass'].text()
+			self.auth()
+			changed = True
+		if self.settings['radioHigh'].isChecked():
+			format = 'mp3-hifi'
+		elif self.settings['radioMed'].isChecked():
+			format = 'mp3'
+		elif self.settings['radioLow'].isChecked():
+			format = 'aacplus'
+		if format != self.c.format:
+			self.c.format=format
+			self.player.format=format
+			self.player.playlist = []
+			self.player.getPlaylist = 1 #Get a new playlist with the new format!
+			changed = True
+		if self.os == "RX-51":
+			self.setAttribute(Qt.WA_Maemo5AutoOrientation, 1)
+		try:
+			if self.settings['radioAuto'].isChecked():
+				self.setAttribute(Qt.WA_Maemo5AutoOrientation, 1)
+			elif self.settings['radioPort'].isChecked():
+				self.setAttribute(Qt.WA_Maemo5PortraitOrientation, 1)
+			elif self.settings['radioLand'].isChecked():
+				self.setAttribute(Qt.WA_Maemo5LandscapeOrientation, 1)
+		except: print "No Rotation."
+		self.settings = None
+		if changed:
+			self.c.write()
+		self.d.close()
 
 	def doSeed( self ):
 		if not self.player.playing:
@@ -222,6 +334,8 @@ class Panda(QtGui.QMainWindow): #main class
 		if self.player.playing:
 			self.player.seedSong = seed
 		self.d.close()
+		if self.os == "RX-51":
+			self.setAttribute(Qt.WA_Maemo5AutoOrientation, 1)
  
 	def open_donate( self ): #Donations are AWESOME :)
 		self.d = QDialog(self)
@@ -249,38 +363,6 @@ class Panda(QtGui.QMainWindow): #main class
 		self.d.setWindowTitle("Donate to:")
 		self.d.show()
 
-	def open_quality( self ): #Quality Selector
-		self.d = QDialog(self)
-		self.d.setParent(self)
-		if self.os == "RX-51":
-			if not self.portrait:
-				self.d.setAttribute(Qt.WA_Maemo5LandscapeOrientation, 1)
-			else:
-				self.d.setAttribute(Qt.WA_Maemo5PortraitOrientation, 1)
-		vbox = QVBoxLayout()
-		hLayout = QHBoxLayout()
-		m = QPushButton("AAC\n(low)")
-		p = QPushButton("MP3\n(Normal)")
-		c = QPushButton("MP3 High\n(Pandora One)")
-		hLayout.addWidget(m)
-		hLayout.addWidget(p)
-		hLayout.addWidget(c)
-		m.clicked.connect(lambda: self.setFormat("aacplus"))
-		p.clicked.connect(lambda: self.setFormat("mp3"))
-		c.clicked.connect(lambda: self.setFormat("mp3-hifi"))
-		vbox.addLayout(hLayout)
-		self.d.setLayout(vbox)
-		self.d.setWindowTitle("Sound Quality:")
-		self.d.show()
-
-	def setFormat(self, format="mp3"): #write quality out to the config file so we can reload later
-		self.c.format=format
-		self.c.write()
-		self.player.format=format
-		self.player.playlist = []
-		self.player.getPlaylist = 1 #Get a new playlist with the new format!
-		self.d.close()
-
 	def donate( self, who=None ):
 		if who == 'radio':		
 			webbrowser.open_new('https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=BWX2M54JBJ2T2')
@@ -296,7 +378,7 @@ class Panda(QtGui.QMainWindow): #main class
 	def setDuration( self ): #Set the song position/duration
 		if (self.player.duration-self.player.position) < self.player.duration:
 			position = "%02d:%02d" % divmod(self.player.duration - self.player.position, 60) + " / " + "%02d:%02d" % divmod(self.player.duration, 60)
-			self.ui.lblTime.setText(position)
+			self.ui.lblTime.setText(position + "\nAlbum: " + self.player.curSong[1]["album"])
 
 	def createStation( self ): #Start the create station sequence
 		if self.os == "RX-51":
@@ -339,7 +421,7 @@ class Panda(QtGui.QMainWindow): #main class
 
 	def sigTired( self ): #Song marked tired successfully 
 		ok = QtGui.QMessageBox.warning(self, "Tired", "Song marked tired.")
-		self.skipSong()
+		self.playNextSong()
 
 	def deleteStation(self): #Start the delete station process
 		if self.os == "RX-51":
@@ -350,7 +432,7 @@ class Panda(QtGui.QMainWindow): #main class
 		reply = QtGui.QMessageBox.question(self, 'Delete Station',
 			"Really delete "+self.ui.listStations.currentText()+"?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
 		if reply == QtGui.QMessageBox.Yes:
-			self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color + ";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/paused-trans.png);")
+			self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color + ";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/Play_small.png);")
 			self.player.stopPlayBack()
 			self.player.deleteStation = 1
 			self.ui.albumArt.setHtml("Please wait...")
@@ -386,33 +468,33 @@ class Panda(QtGui.QMainWindow): #main class
 			self.fmtx_iface.Set("com.nokia.FMTx.Device", "state", dbus.String(u'%s' % 'disabled', variant_level=1))
 
 	def nextDown(self): #change button color
-		self.ui.btnNext.setStyleSheet("background-color: " + self.c.color + ";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/skip-trans.png);")
+		self.ui.btnNext.setStyleSheet("background-color: " + self.c.color + ";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/next_small.png);")
 
 	def nextUp(self): #change button color
-		self.ui.btnNext.setStyleSheet("background-color: rgb(0, 0, 0);\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/skip-trans.png);")
+		self.ui.btnNext.setStyleSheet("background-color: rgb(0, 0, 0);\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/next_small.png);")
 
 	def doPlayPause( self, signal=None ): #Play if stopped, pause if playing, receive signals from Backend if changed from somewhere else (ie: headphones)
 		if self.player.playing:
 			if signal != "play":
 				self.player.stopPlayBack('pause')
-				self.player.playing = 0
-				self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color +";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/paused-trans.png);")
+				self.player.playing = False
+				self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color +";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/Play_small.png);")
 		elif self.player.playlist != []:
 			if signal != "pause":
 				self.player.startPlayBack()
-				self.player.playing = 1
-				self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color +";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/playing-trans.png);")
+				self.player.playing = True
+				self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color +";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/Play_small.png);")
 		else:
 			self.playStation()
-			self.player.playing = 1
-			self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color +";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/playing-trans.png);")
+			self.player.playing = True
+			self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color +";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/Play_small.png);")
 
 	def doLove( self ): #Love this song
 		self.player.loveHateRating = True
 		self.player.loveHateSong = 1
 		self.player.curSong[1]["rating"] = 1
 		self.ui.btnLove.setStyleSheet("background-color: "+ self.c.color +";\n"
-		"border: rgb(0, 0, 0);\nbackground-image: url(:/img/img/Thumbs-up-right-trans.png);")
+		"border: rgb(0, 0, 0);\nbackground-image: url(:/img/img/thumbup_small.png);")
 
 	def doHate( self ): #Hate this song
 		self.player.loveHateRating = False
@@ -422,15 +504,15 @@ class Panda(QtGui.QMainWindow): #main class
 	def sigLoveHate( self ): #Signal for Love/Hate from backend
 		if not self.player.respLH:
 			self.ui.btnLove.setStyleSheet("background-color: "+ self.c.color +";\n"
-			"border: rgb(0, 0, 0);\nbackground-image: url(:/img/img/Thumbs-up-right.png);")
+			"border: rgb(0, 0, 0);\nbackground-image: url(:/img/img/thumbup_small.png);")
 		if self.skip:
-			self.skipSong()
+			self.playNextSong()
 
 	def hateDown(self): #change button color
-		self.ui.btnHate.setStyleSheet("background-color: " + self.c.color + ";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/thumbs-down-trans.png);")
+		self.ui.btnHate.setStyleSheet("background-color: " + self.c.color + ";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/thumbdwn_small.png);")
 
 	def hateUp(self): #change button color
-		self.ui.btnHate.setStyleSheet("background-color: rgb(0, 0, 0);\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/thumbs-down-trans.png);")
+		self.ui.btnHate.setStyleSheet("background-color: rgb(100, 100, 100);\nborder: rgb(255, 255, 255);\nbackground-image: url(:/img/img/thumbdwn_small.png);")
 
 	def sigAuth( self ): #Signal for authentication success/failure.
 		if self.player.success:
@@ -484,10 +566,7 @@ class Panda(QtGui.QMainWindow): #main class
 		self.player.curStation = stationId
 		self.player.playlist = []
 		self.player.getMoreSongs()
-		self.player.playing = True
 		self.playNextSong()
-		#if self.player.playing:
-			#self.player.stopPlayBack()
 		if stationId != self.c.lastplayed:
 			f = open(os.path.expanduser("~")+'/.config/pyradio/lastplayed', 'w')
 			f.write(self.player.curStation)
@@ -502,6 +581,7 @@ class Panda(QtGui.QMainWindow): #main class
 		self.ui.btnHate.setEnabled( True )
 		self.ui.btnSleep.setEnabled( True )
 		self.ui.btnNext.setEnabled( True )
+		self.ui.lblTime.setWordWrap( True )
 
 		self.buildPlaylist()
 
@@ -534,14 +614,16 @@ class Panda(QtGui.QMainWindow): #main class
 		self.auth()
 
 	def playNextSong( self ): #Go to next song in playlist
-		if not self.player.playing:
-			raise PandaException()
-		while self.player.playlist == []:
+		try:
+			next = self.player.playlist.pop( 0 )
+		except:
 			self.player.getMoreSongs()
-		next = self.player.playlist.pop( 0 )
-		#print next
+			next = self.player.playlist.pop( 0 )
+
+		print "Playing Next Song"
+		self.skip = 0
 		self.player.curSong = next
-		self.player.startPlay = 1
+		self.player.playSong ( next )
 		self.setUi ( next )
 		if self.player.playlist == []:
 			#Out of songs, grab some more while playing
@@ -550,20 +632,16 @@ class Panda(QtGui.QMainWindow): #main class
 	def setUi ( self, next=None ): #Update the album graphic and set Love graphic
 		art = next[1]["art"]
 		self.ui.albumArt.setHtml("<table width='100%' height='100%'><tr><td vertical-align='middle' style='text-align: center'><img style='width: 80%; height: 100%' src='"+art+"'></td></tr></table>")
-		self.ui.lblAlbum.setText("\"" + next[1]["title"] + "\"" + " by " + next[1]["artist"] + "\n" + "on: " + next[1]["album"])
+		self.ui.lblSong.setText("\"" + next[1]["title"] + "\"\nArtist: " + next[1]["artist"])
 		if next[1]["rating"] > 0:
 			self.ui.btnLove.setStyleSheet("background-color: "+ self.c.color + ";\n"
-			"border: rgb(0, 0, 0);\nbackground-image: url(:/img/img/Thumbs-up-right-trans.png);")
+			"border: rgb(0, 0, 0);\nbackground-image: url(:/img/img/thumbup_small.png);")
 		else:
-			self.ui.btnLove.setStyleSheet("background-image: url(:/img/img/Thumbs-up-right-trans.png);\nborder: rgb(0, 0, 0);\nbackground-color: rgb(0, 0, 0);")
+			self.ui.btnLove.setStyleSheet("background-image: url(:/img/img/thumbup_small.png);\nborder: rgb(0, 0, 0);\nbackground-color: rgb(100, 100, 100);")
 
-		self.ui.btnPlay.setStyleSheet("background-image: url(:/img/img/playing-trans.png);\nborder: rgb(0, 0, 0);\nbackground-color: "+ self.c.color + ";")
+		self.ui.btnPlay.setStyleSheet("background-image: url(:/img/img/Play_small.png);\nborder: rgb(0, 0, 0);\nbackground-color: "+ self.c.color + ";")
 		self.ui.btnNext.setEnabled( True )
 
-	def skipSong( self ): #Skip song
-		self.skip = 0
-		self.player.stopPlayBack()
-
 	def stop( self ): #Stop Playing, not currently implemented
 		self.player.playing = False
 
