@@ -20,6 +20,7 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 		self.success = 0
 		self.duration = 0
 		self.position = 0
+		self.volume = 0
 
 		self.state = 1
 		self.seedSong = 0
@@ -44,7 +45,6 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 		QtCore.QObject.connect(self.player, QtCore.SIGNAL("eof"), self.sigEOF)
 		QtCore.QObject.connect(self.player, QtCore.SIGNAL("state_change(int)"), self.stateChange)
 		QtCore.QObject.connect(self.player, QtCore.SIGNAL("pos_changed(int,int)"), self.updateTime)
-		self.stop = True
 		self.playStation = 0
 		self.stations = []
 		self.curStation = ""
@@ -58,31 +58,40 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 	def run(self):
 		while self.run: #Run a constant loop and see if the main UI class has asked us to do anything
 			if self.loveHateSong:
+				print "Thumbing song"
 				self.loveHateSong = 0
 				self.LoveHate()
 				self.loveHateRating = False
 			if self.getStatlist:
+				print "Getting Stations"
 				self.getStatlist = 0
 				self.getStations()
 			if self.getPlaylist:
+				print "Getting More Songs"
 				self.getPlaylist = 0
 				self.getMoreSongs()
 			if self.startPlay:
+				print "Startplay Called."
 				self.startPlay = 0 
 				self.playSong( self.curSong )
 			if self.tiredSong:
+				print "Marking song Tired."
 				self.tiredSong = 0
 				self.doTired()
 			if self.deleteStation:
+				print "Deleting Station."
 				self.deleteStation = 0
 				self.doDelete()
 			if self.doAuth:
+				print "Authenticating"
 				self.doAuth = 0
 				self.auth( self.user, self.password )
 			if self.createStationId>0:
+				print "Creating Station."
 				self.createStation()
 				self.createStationId = 0
 			if self.seedSong!=0:
+				print "Adding Seed."
 				self.doSeed(self.seedSong)
 				self.seedSong = 0
 
@@ -118,8 +127,6 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 			self.emit(QtCore.SIGNAL("state(QString)"),"pause")
 		elif state == 1:
 			self.emit(QtCore.SIGNAL("state(QString)"),"play")
-		elif state == 0:
-			self.onPlayBackEnded()
 
 	def createStation( self ): #Create a station at Pandora
 		ret = self.pandora.createStation( self.createStationId )
@@ -144,27 +151,22 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 		self.play( item[0], item[1] )
 
 	def play( self, url, item ): #Load URL/Song into Backend
+		self.playing = True
 		self.player.load_audio(url)
 
 	def stopPlayBack ( self,state=None ): #Pause or Stop
 		if state == 'pause':
 			self.player.pause()
-		else:
-			if self.os == "RX-51":
-				self.player.close()
-			else:
-				self.player.stop()
-				self.onPlayBackEnded()		
-	
+
 	def startPlayBack ( self ): #Resume after Pause
 		self.player.play()
 
-	def onPlayBackEnded( self ): #EOF Reached, start next song.
-		print "EOF called."
+	def onPlayBackEnded( self ): #Start next song.
 		self.emit(QtCore.SIGNAL("PlayNext"))
 		
 	def sigEOF( self ):
-		if self.os != "RX-51":
+		if self.playing and self.position > 10: # Trying to fix issues with skipping.  EOF gets called at unexpected times.	
+			print "EOF called."
 			self.onPlayBackEnded()
 
 	def LoveHate( self ): #Do Love/Hate based on variable settings
